@@ -34,7 +34,6 @@ class PeakSortingMethod(AlgoParamEnum):
 class ProcessorSpec:
     processor_config: ProcessorConfig = attrs.field()
     group_index: int = attrs.field()
-    sensor_id: int = attrs.field()
     subsweep_indexes: list[int] = attrs.field()
     processor_context: Optional[ProcessorContext] = attrs.field(default=None)
 
@@ -48,6 +47,7 @@ class AggregatorConfig:
 class AggregatorResult:
     processor_results: list[ProcessorResult] = attrs.field()
     estimated_distances: npt.NDArray[np.float_] = attrs.field()
+    estimated_rcs: npt.NDArray[np.float_] = attrs.field()
     service_extended_result: list[dict[int, a121.Result]] = attrs.field()
 
 
@@ -75,15 +75,17 @@ class Aggregator:
         extended_metadata: list[dict[int, a121.Metadata]],
         config: AggregatorConfig,
         specs: list[ProcessorSpec],
+        sensor_id: int,
     ):
         self.config = config
         self.specs = specs
+        self.sensor_id = sensor_id
 
         self.processors: list[Processor] = []
 
         for spec in specs:
-            metadata = extended_metadata[spec.group_index][spec.sensor_id]
-            sensor_config = session_config.groups[spec.group_index][spec.sensor_id]
+            metadata = extended_metadata[spec.group_index][self.sensor_id]
+            sensor_config = session_config.groups[spec.group_index][self.sensor_id]
 
             processor = Processor(
                 sensor_config=sensor_config,
@@ -101,7 +103,7 @@ class Aggregator:
         rcs: npt.NDArray[np.float_] = np.array([])
 
         for spec, processor in zip(self.specs, self.processors):
-            processor_result = processor.process(extended_result[spec.group_index][spec.sensor_id])
+            processor_result = processor.process(extended_result[spec.group_index][self.sensor_id])
             processors_result.append(processor_result)
             if processor_result.estimated_distances is not None:
                 assert spec.processor_context is not None
@@ -145,13 +147,14 @@ class Aggregator:
         (dists_merged, ampls_merged, rcs_merged) = self._merge_peaks(
             self.MIN_PEAK_DIST_M, dists, ampls, rcs
         )
-        dists_sorted = self._sort_peaks(
+        (dists_sorted, rcs_sorted) = self._sort_peaks(
             dists_merged, ampls_merged, rcs_merged, self.config.peak_sorting_method
         )
 
         return AggregatorResult(
             processor_results=processors_result,
             estimated_distances=dists_sorted,
+            estimated_rcs=rcs_sorted,
             service_extended_result=extended_result,
         )
 
@@ -196,16 +199,19 @@ class Aggregator:
 
         peak_cluster_idxs = np.where(min_peak_to_peak_dist < np.diff(distances_sorted))[0] + 1
         distances_merged = [
-            np.mean(cluster) if dists.size != 0 else np.nan
+            np.mean(cluster)
             for cluster in np.split(distances_sorted, peak_cluster_idxs)
+            if dists.size != 0
         ]
         amplitudes_merged = [
-            np.mean(cluster) if dists.size != 0 else np.nan
+            np.mean(cluster)
             for cluster in np.split(amplitudes_sorted, peak_cluster_idxs)
+            if dists.size != 0
         ]
         rcs_merged = [
-            np.mean(cluster) if dists.size != 0 else np.nan
+            np.mean(cluster)
             for cluster in np.split(rcs_sorted, peak_cluster_idxs)
+            if dists.size != 0
         ]
         return (np.array(distances_merged), np.array(amplitudes_merged), np.array(rcs_merged))
 
@@ -215,14 +221,17 @@ class Aggregator:
         ampls: npt.NDArray[np.float_],
         rcs: npt.NDArray[np.float_],
         method: PeakSortingMethod,
-    ) -> npt.NDArray[np.float_]:
+    ) -> Tuple[npt.NDArray[np.float_], npt.NDArray[np.float_]]:
         if method == PeakSortingMethod.CLOSEST:
             quantity_to_sort = dists
         elif method == PeakSortingMethod.HIGHEST_RCS:
             quantity_to_sort = -rcs
         else:
             raise ValueError("Unknown peak sorting method")
-        return np.array([dists[i] for i in quantity_to_sort.argsort()])
+        return (
+            np.array([dists[i] for i in quantity_to_sort.argsort()]),
+            np.array([rcs[i] for i in quantity_to_sort.argsort()]),
+        )
 
     @classmethod
     def _get_rcs_of_peaks(
