@@ -190,7 +190,7 @@ class BackendPlugin(DetectorBackendPluginBase[SharedState]):
 
         self._detector_instance = Detector(
             client=self._client,
-            sensor_id=self.shared_state.sensor_id,
+            sensor_ids=[self.shared_state.sensor_id],
             detector_config=self.shared_state.config,
             context=self.shared_state.context,
         )
@@ -295,7 +295,7 @@ class BackendPlugin(DetectorBackendPluginBase[SharedState]):
         try:
             self._detector_instance = Detector(
                 client=self._client,
-                sensor_id=self.shared_state.sensor_id,
+                sensor_ids=[self.shared_state.sensor_id],
                 detector_config=self.shared_state.config,
                 context=self.shared_state.context,
             )
@@ -305,11 +305,14 @@ class BackendPlugin(DetectorBackendPluginBase[SharedState]):
         finally:
             self.callback(PluginStateMessage(state=PluginState.LOADED_IDLE))
 
-        self.shared_state.context = self._detector_instance.context
+        self.shared_state.context = self._detector_instance.multi_sensor_context
         self.broadcast()
 
 
 class PlotPlugin(DetectorPlotPluginBase):
+
+    _DISTANCE_HISTORY_PLOT_HALF_SPAN = 0.2
+
     def __init__(self, *, plot_layout: pg.GraphicsLayout, app_model: AppModel) -> None:
         super().__init__(plot_layout=plot_layout, app_model=app_model)
 
@@ -368,11 +371,17 @@ class PlotPlugin(DetectorPlotPluginBase):
         self.sweep_smooth_max = et.utils.SmoothMax()
         self.distance_hist_smooth_lim = et.utils.SmoothLimits()
 
-    def update(self, result: DetectorResult) -> None:
+    def update(self, multi_sensor_result: dict[int, DetectorResult]) -> None:
+        # Get the first element as the plugin only supports single sensor operation.
+        (result,) = list(multi_sensor_result.values())
+
         assert result.distances is not None
 
         self.distance_history.pop(0)
-        self.distance_history.append(result.distances[0])
+        if len(result.distances) != 0:
+            self.distance_history.append(result.distances[0])
+        else:
+            self.distance_history.append(np.nan)
 
         max_val_in_plot = 0
         for idx, processor_result in enumerate(result.processor_results):
@@ -395,8 +404,11 @@ class PlotPlugin(DetectorPlotPluginBase):
 
         if np.any(~np.isnan(self.distance_history)):
             self.dist_history_curve.setData(self.distance_history)
+            distance_span = distances_m[-1] - distances_m[0]
             lims = self.distance_hist_smooth_lim.update(self.distance_history)
-            self.dist_history_plot.setYRange(lims[0], lims[1])
+            lower_lim = max(0.0, lims[0] - distance_span * self._DISTANCE_HISTORY_PLOT_HALF_SPAN)
+            upper_lim = lims[1] + distance_span * self._DISTANCE_HISTORY_PLOT_HALF_SPAN
+            self.dist_history_plot.setYRange(lower_lim, upper_lim)
         else:
             self.dist_history_curve.setData([])
 
@@ -405,6 +417,7 @@ class ViewPlugin(DetectorViewPluginBase):
 
     TEXT_MSG_MAP = {
         DetailedStatus.OK: "Ready to start.",
+        DetailedStatus.CONTEXT_MISSING: "Run detector calibration.",
         DetailedStatus.CALIBRATION_MISSING: "Run detector calibration.",
         DetailedStatus.CONFIG_MISMATCH: (
             "Current configuration does not match the configuration "
@@ -599,7 +612,7 @@ class ViewPlugin(DetectorViewPluginBase):
         self.sensor_id_pidget.setEnabled(app_model.plugin_state.is_steady)
 
         detector_status = Detector.get_detector_status(
-            state.config, state.context, state.sensor_id
+            state.config, state.context, [state.sensor_id]
         )
 
         self.message_box.setText(self.TEXT_MSG_MAP[detector_status.detector_state])
@@ -608,7 +621,6 @@ class ViewPlugin(DetectorViewPluginBase):
             app_model.plugin_state == PluginState.LOADED_IDLE
             and app_model.connection_state == ConnectionState.CONNECTED
         )
-
         self.calibrate_detector_button.setEnabled(ready_for_session)
         self.start_button.setEnabled(ready_for_session and detector_status.ready_to_start)
         self.stop_button.setEnabled(app_model.plugin_state == PluginState.LOADED_BUSY)
