@@ -11,6 +11,7 @@ def load_default_plugins() -> list[PluginSpec]:
     from acconeer.exptool.a121.algo.phase_tracking._plugin import PHASE_TRACKING_PLUGIN
     from acconeer.exptool.a121.algo.presence._detector_plugin import PRESENCE_DETECTOR_PLUGIN
     from acconeer.exptool.a121.algo.sparse_iq._plugin import SPARSE_IQ_PLUGIN
+    from acconeer.exptool.a121.algo.vibration._plugin import VIBRATION_PLUGIN
     from acconeer.exptool.a121.algo.virtual_button._plugin import VIRTUAL_BUTTON_PLUGIN
 
     return [
@@ -19,4 +20,5 @@ def load_default_plugins() -> list[PluginSpec]:
         PHASE_TRACKING_PLUGIN,
         PRESENCE_DETECTOR_PLUGIN,
         VIRTUAL_BUTTON_PLUGIN,
+        VIBRATION_PLUGIN,
     ]
